<?php
// $Id$

/**
 * Add a display handler that will use the Drupal core method of display.
 */
class TaxonomyDisplayTermDisplayHandlerCore extends TaxonomyDisplayTermDisplayHandler {
  /**
   * Build our output to be rendered to the user.
   *
   * @see TaxonomyDisplayTermDisplayHandler::displayTerm()
   */
  public function displayTerm($term, $options = NULL) {
    $build = array();

    // Allow display of term's additional content even if the description field
    // is blank, if the option is enabled.
    // @see http://drupal.org/node/796692
    if ($options && $options['display_fields_description_empty']) {
      $build = array(
        '#prefix' => '<div class="term-listing-heading">',
        '#suffix' => '</div>',
        'term' => taxonomy_term_view($term, 'full'),
      );
      if (empty($term->description)) {
        unset($build['description']);
      }
    }
    elseif (!empty($term->description)) {
      $build = array(
        '#prefix' => '<div class="term-listing-heading">',
        '#suffix' => '</div>',
        'term' => taxonomy_term_view($term, 'full'),
      );
    }

    return $build;
  }

  /**
   * Build our form for the fieldset.
   *
   * @see TaxonomyDisplayHandlerForm::formFieldset()
   */
  public function formFieldset(&$form, &$values, $options = NULL) {
    $form['#description'] = t('The core Drupal functionality will be used to display the term.');

    $form['display_fields_description_empty'] = array(
      '#default_value' => isset($options['display_fields_description_empty']) ? $options['display_fields_description_empty'] : 0,
      '#description' => t('If a taxonomy term does not have a description entered Drupal core will not display any of its fields. Selecting <em>yes</em> will overcome <a href="!link">this problem</a>.', array('!link' => url('http://drupal.org/node/796692'))),
      '#options' => array(t('No'), t('Yes')),
      '#title' => t('Render term when the description field is empty?'),
      '#type' => 'radios',
    );
  }

  /**
   * We store values to access later for rendering and editing.
   *
   * @see TaxonomyDisplayHandlerForm::formSubmit()
   */
  public function formSubmit($form, &$values) {
    // We are using the exact keys that our formFieldset() implementation
    // defines and we want all of the values stored, so we have no need to alter
    // them before returning.
    return $values;
  }
}
